@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-12-15 13:41:49
+@LastEditTime: 2021-12-21 19:50:31
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -30,7 +30,8 @@ class TaskInfoListHandler(ClientBaseHandler):
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         task_types = self.get_param("task_types")
-        is_log = self.get_param("is_log", False)
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
         task_base_model = TaskBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
         invoke_result_data = self.business_process_executing()
