@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-12-21 10:26:56
+@LastEditTime: 2021-12-21 19:50:42
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -141,7 +141,9 @@ class CheckIsMemberHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        is_log = bool(self.get_param("is_log", False))
+        mix_nick = self.get_param("mix_nick")
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         if not app_info_dict:
@@ -151,7 +153,7 @@ class CheckIsMemberHandler(ClientBaseHandler):
             return self.response_json_error("error", "未授权请联系客服授权")
         top_base_model = TopBaseModel(context=self)
         app_key,app_secret = self.get_app_key_secret()
-        return self.response_json_success(top_base_model.check_is_member(access_token, app_key, app_secret, is_log))
+        return self.response_json_success(top_base_model.check_is_member(mix_nick,"", access_token, app_key, app_secret, is_log))
 
 
 class ApplyBlackUnbindHandler(ClientBaseHandler):
@@ -219,7 +221,8 @@ class GetCouponPrizeHandler(ClientBaseHandler):
         app_id = self.get_source_app_id()
         open_id = self.get_param("open_id")
         user_prize_id = int(self.get_param("user_prize_id", 0))
-        is_log = bool(self.get_param("is_log", False))
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         if not app_info_dict:
@@ -338,7 +341,8 @@ class GetJoinMemberUrlHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        is_log = bool(self.get_param("is_log",False))
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         if not app_info_dict:
