@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 17:00:55
-@LastEditTime: 2021-11-29 16:38:49
+@LastEditTime: 2021-12-07 19:03:20
 @LastEditors: HuangJianYi
 @Description: 基础模块
 """
@@ -200,11 +200,16 @@ class CmsInfoListHandler(ClientBaseHandler):
         place_id = int(self.get_param("place_id", 0))
         page_size = int(self.get_param("page_size", 20))
         page_index = int(self.get_param("page_index", 0))
-        
+
+        order_by = "id desc"
+        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
+        else:
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         cms_base_model = CmsBaseModel(context=self)
-        page_list, total = self.business_process_executed(cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, app_id=app_id, act_id=act_id, is_cache=False), ref_params={})
+        page_list, total = self.business_process_executed(cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=False), ref_params={})
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
         return self.response_json_success(page_info)
\ No newline at end of file
