@@ -2,9 +2,9 @@
 """
 :Author: HuangJianYi
 :Date: 2020-11-16 13:44:20
-@LastEditTime: 2021-11-19 09:28:59
+@LastEditTime: 2021-11-29 16:40:24
 @LastEditors: HuangJianYi
-:description: 
+:description: 报表模块
 """
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.stat_base_model import *
@@ -38,15 +38,6 @@ class StatReportListHandler(ClientBaseHandler):
         stat_report_list = self.business_process_executed(stat_report_list, ref_params)
         return self.response_json_success(stat_report_list)
 
-    def business_process_executed(self, result_data, ref_params):
-        """
-        :description: 执行后事件
-        :param result_data:result_data
-        :param ref_params: 关联参数
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return result_data
 
 
 class TrendReportListHandler(ClientBaseHandler):
@@ -77,12 +68,3 @@ class TrendReportListHandler(ClientBaseHandler):
         trend_report_list = self.business_process_executed(trend_report_list, ref_params)
         return self.response_json_success(trend_report_list)
 
-    def business_process_executed(self, result_data, ref_params):
-        """
-        :description: 执行后事件
-        :param result_data:result_data
-        :param ref_params: 关联参数
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return result_data
