@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-01-14 10:44:07
-@LastEditTime: 2021-10-12 17:52:14
+@LastEditTime: 2021-11-11 13:37:08
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -52,9 +52,9 @@ class TikTokHelper:
         }
         response = None
         try:
-            requset_url = 'https://developer.toutiao.com/api/apps/jscode2session'
+            requset_url = 'https://developer.toutiao.com/api/apps/v2/jscode2session'
             headers = {"Content-type": "application/json"}
-            response = requests.post(requset_url, headers=headers, data=SevenHelper.json_dumps(param))
+            response = requests.post(requset_url, headers=headers, data=json.dumps(param))
             response_data = SevenHelper.json_loads(response.text)
             if response_data.__contains__("err_no") and response_data["err_no"] != 0:
                 invoke_result_data.success = False
@@ -65,10 +65,10 @@ class TikTokHelper:
             session_key = response_data["data"]['session_key']
             redis_init.set(redis_key, SevenHelper.json_dumps(response_data["data"]), ex=60 * 60)
             redis_init.set(f"{app_id}_tiktok_sessionkey:{str(open_id)}", session_key, ex=60 * 60)
-            invoke_result_data.data = response_data
+            invoke_result_data.data = response_data["data"]
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【code2_session】" + traceback.format_exc() + ":" + str(response.text))
+            self.logger_error.error("【code2_session】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = traceback.format_exc()
@@ -97,7 +97,7 @@ class TikTokHelper:
         try:
             requset_url = 'https://developer.toutiao.com/api/apps/token'
             headers = {"Content-type": "application/json"}
-            response = requests.post(requset_url, headers=headers, data=SevenHelper.json_dumps(param))
+            response = requests.post(requset_url, headers=headers, data=json.dumps(param))
             response_data = SevenHelper.json_loads(response.text)
             if response_data.__contains__("err_no") and response_data["err_no"] != 0:
                 invoke_result_data.success = False
@@ -107,7 +107,7 @@ class TikTokHelper:
             invoke_result_data.data = response_data["data"]
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【get_access_token】" + traceback.format_exc() + ":" + str(response.text))
+            self.logger_error.error("【get_access_token】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = traceback.format_exc()
@@ -190,7 +190,7 @@ class TikTokHelper:
         try:
             requset_url = 'https://developer.toutiao.com/api/apps/token'
             headers = {"Content-type": "application/json"}
-            response = requests.post(requset_url, headers=headers, data=SevenHelper.json_dumps(param))
+            response = requests.post(requset_url, headers=headers, data=json.dumps(param))
             response_data = SevenHelper.json_loads(response.text)
             if response_data["errcode"] != 0:
                 invoke_result_data.success = False
@@ -208,13 +208,11 @@ class TikTokHelper:
 
 class TikTokPayRequest(object):
     """
-    :description: 抖音支付请求类,配置文件内容 "tiktok_pay": {"api_key": "","cp_extra": "","token": "","salt": "","pay_notify_url": ""}
+    :description: 抖音支付请求类,配置文件内容 "tiktok_pay": {"cp_extra": "","token": "","salt": ""}
     """
     # =======【基本信息设置】=====================================
     # 抖音公众号身份的唯一标识。审核通过后，在抖音发送的邮件中查看
     app_id = ""
-    # API密钥，需要在商户后台设置
-    api_key = ""
     #开发者自定义字段，回调原样回传
     cp_extra = ""
     #担保交易Token（令牌）
@@ -224,58 +222,55 @@ class TikTokPayRequest(object):
     # 日志
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, app_id="", api_key="", cp_extra="", token="", salt=""):
+    def __init__(self, app_id="", cp_extra="", token="", salt=""):
         """
         :description: 初始化
         :last_editors: HuangJianYi
         """
         pay_config = config.get_value("tiktok_pay")
         self.app_id = app_id if app_id else config.get_value("app_id")
-        self.api_key = api_key if api_key else pay_config["api_key"]
         self.cp_extra = cp_extra if cp_extra else pay_config["cp_extra"]
         self.token = token if token else pay_config["token"]
         self.salt = salt if salt else pay_config["salt"]
 
-    def create_order(self, pay_order_no, notify_url, total_amount=1, subject="", body="", valid_time=900, thirdparty_id="", disable_msg=None, msg_page="", store_uid=""):
+    def create_order(self, pay_order_no, notify_url, total_amount=1, subject="", body="", valid_time=900, thirdparty_id="", disable_msg=None, msg_page=""):
         """
         :description: 服务端创建预下单
         :param pay_order_no：商户订单号(支付单号)开发者服务端的唯一订单号
         :param notify_url：支付结果异步通知地址
-        :param total_amount:支付价格; 接口中参数支付金额单位为[分]|默认 1
+        :param total_amount:支付价格;单位元
         :param subject: 商品描述; 长度限制 128 字节，不超过 42 个汉字 |默认 自己约定一个比如 “福小宠商品”*|
         :param body:商品详情|默认 自己约定一个比如 “福小宠商品”
         :param valid_time:订单过期时间(秒); 最小 15 分钟，最大两天|默认 900
         :param thirdparty_id:服务商模式接入必传,第三方平台服务商 id，非服务商模式留空|默认传空字符串
         :param disable_msg:是否屏蔽担保支付的推送消息，1-屏蔽 0-非屏蔽，接入 POI 必传|默认传None
         :param msg_page:担保支付消息跳转页|默认传空字符串
-        :param store_uid:多门店模式下必传,多门店模式下，门店 uid|默认传空字符串
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         try:
             data = {}
+            data['app_id'] = self.app_id
             data['out_order_no'] = pay_order_no
-            data['cp_extra'] = self.cp_extra
-            data['notify_url'] = notify_url
-            data['total_amount'] = str(int(decimal.Decimal(str(total_amount)) * 100))
+            data['total_amount'] = int(decimal.Decimal(str(total_amount)) * 100)
             data['subject'] = subject
             data['body'] = body
             data['valid_time'] = valid_time
+            if notify_url:
+                data['notify_url'] = notify_url
+            if self.cp_extra:
+                data['cp_extra'] = self.cp_extra
             if disable_msg:
                 data['disable_msg'] = int(disable_msg)
             if msg_page:
                 data['msg_page'] = msg_page
-            if store_uid:
-                data['store_uid'] = store_uid
-
-            sign = self._get_tt_sign(data)
-            # 如果有第三方平台服务商id:thirdparty_id字段请把他放入data的字典里面
-            data['sign'] = sign
-            data['app_id'] = self.app_id
-
             if thirdparty_id:
                 data['thirdparty_id'] = thirdparty_id
 
+            sign = self.get_sign(data)
+            # 如果有第三方平台服务商id:thirdparty_id字段请把他放入data的字典里面
+            data['sign'] = sign
+
             redis_key = f"{self.app_id}_tiktok_order_id:{str(pay_order_no)}"
             orderInfo = SevenHelper.redis_init().get(redis_key)
             if orderInfo:
@@ -284,7 +279,7 @@ class TikTokPayRequest(object):
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/create_order"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response = requests.post(url, headers=headers, data=json.dumps(data))
             response_data = SevenHelper.json_loads(response.text)
             # err_no	number	    状态码 0-业务处理成功
             # err_tips	string	    错误提示信息，常见错误处理可参考附录常见问题章节
@@ -319,7 +314,7 @@ class TikTokPayRequest(object):
             app_id = self.app_id
             data = {}
             data['out_order_no'] = pay_order_no
-            sign = self._get_tt_sign(data)
+            sign = self.get_sign(data)
             data['sign'] = sign
             data['app_id'] = app_id
             if thirdparty_id:
@@ -327,7 +322,7 @@ class TikTokPayRequest(object):
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/query_order"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response = requests.post(url, headers=headers, data=json.dumps(data))
             response_data = SevenHelper.json_loads(response.text)
             # {"err_no": 2000, "err_tips": "单号记录不存在", "out_order_no": "", "order_id": "", "payment_info": null}
             # payment_info 返回值结构如下：
@@ -381,7 +376,7 @@ class TikTokPayRequest(object):
         :param refund_no:开发者侧的退款单号, 不可重复
         :param pay_order_no:商户分配订单号，标识进行退款的订单，开发者服务端的唯一订单号
         :param notify_url:退款通知地址
-        :param refund_amount: 退款金额，单位[分]|默认 1
+        :param refund_amount: 退款金额；单位元
         :param reason:退款理由，长度上限 100|默认 由开发者定 例如：“7天无理由退款”
         :param thirdparty_id:服务商模式接入必传,第三方平台服务商 id，非服务商模式留空|默认传空字符串
         :param disable_msg:是否屏蔽担保支付的推送消息，1-屏蔽 0-非屏蔽，接入 POI 必传|默认传None
@@ -391,38 +386,39 @@ class TikTokPayRequest(object):
         """
         invoke_result_data = InvokeResultData()
         try:
-            app_id = self.app_id
             data = {}
+            data['app_id'] = self.app_id
             data['out_refund_no'] = refund_no
-            #cp_extra 开发者自定义字段，回调原样回传
-            data['cp_extra'] =  self.cp_extra
-            data['notify_url'] = notify_url
             data['out_order_no'] = pay_order_no
-            data['refund_amount'] = str(int(decimal.Decimal(str(refund_amount)) * 100))
+            data['refund_amount'] = int(decimal.Decimal(str(refund_amount)) * 100)
             data['reason'] = reason
+            #cp_extra 开发者自定义字段，回调原样回传
+            if self.cp_extra:
+                data['cp_extra'] = self.cp_extra
+            if notify_url:
+                data['notify_url'] = notify_url
             if disable_msg:
                 data['disable_msg'] = int(disable_msg)
             if msg_page:
                 data['msg_page'] = msg_page
             if all_settle:
                 data['all_settle'] = int(all_settle)
-
-            sign = self._get_tt_sign(data)
-            # 如果有第三方平台服务商 id :thirdparty_id字段请把他放入data.update的字典里面
-            data['sign'] = sign
-            data['app_id'] = app_id
             if thirdparty_id:
                 data['thirdparty_id'] = thirdparty_id
 
+            sign = self.get_sign(data)
+            # 如果有第三方平台服务商 id :thirdparty_id字段请把他放入data.update的字典里面
+            data['sign'] = sign
+
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/create_refund"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response = requests.post(url, headers=headers, data=json.dumps(data))
             response_data = SevenHelper.json_loads(response.text)
             if response_data['err_no'] == 0:
                 invoke_result_data.data = response_data
                 return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【退款】" + traceback.format_exc())
+            self.logger_error.error("【创建退款单】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "退款出现异常，请重试"
@@ -440,7 +436,7 @@ class TikTokPayRequest(object):
             app_id = self.app_id
             data = {}
             data['out_refund_no'] = refund_no
-            sign = self._get_tt_sign(data)
+            sign = self.get_sign(data)
             data['sign'] = sign
             data['app_id'] = app_id
             if thirdparty_id:
@@ -448,7 +444,7 @@ class TikTokPayRequest(object):
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/query_refund"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response = requests.post(url, headers=headers, data=json.dumps(data))
             response_data = SevenHelper.json_loads(response.text)
             if response_data['err_no'] == 0:
                 invoke_result_data.data = response_data
@@ -488,7 +484,7 @@ class TikTokPayRequest(object):
             data['settle_desc'] = settle_desc
             if settle_params:
                 data['settle_params'] = settle_params
-            sign = self._get_tt_sign(data)
+            sign = self.get_sign(data)
             data['sign'] = sign
             data['app_id'] = app_id
             if thirdparty_id:
@@ -496,7 +492,7 @@ class TikTokPayRequest(object):
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/settle"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response = requests.post(url, headers=headers, data=json.dumps(data))
             response_data = SevenHelper.json_loads(response.text)
             if response_data['err_no'] == 0:
                 invoke_result_data.data = response_data
@@ -521,7 +517,7 @@ class TikTokPayRequest(object):
             app_id = self.app_id
             data = {}
             data['out_settle_no'] = out_settle_no
-            sign = self._get_tt_sign(data)
+            sign = self.get_sign(data)
             data['sign'] = sign
             data['app_id'] = app_id
             if thirdparty_id:
@@ -529,7 +525,7 @@ class TikTokPayRequest(object):
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/query_settle"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response = requests.post(url, headers=headers, data=json.dumps(data))
             response_data = SevenHelper.json_loads(response.text)
             if response_data['err_no'] == 0:
                 invoke_result_data.data = response_data
@@ -542,23 +538,23 @@ class TikTokPayRequest(object):
             invoke_result_data.error_message = "结算查询出现异常，请重试"
             return invoke_result_data
 
-    def _get_tt_sign(self, params):
-        """
-        :description: 获取头条请求sign
-        :param params: 参数字典
-        :return: sign
-        :last_editors: HuangJianYi
-        """
-        params_copy = copy.deepcopy(params)
-        for key, value in params_copy.items():
-            if isinstance(value, int):
-                params_copy[key] = str(value)
-        params_copy['salt'] = self.salt
-        # params_copy['salt'] = 'your_payment_salt'
-        params_list = sorted(list(params_copy.items()), key=lambda x: x[1])
-        params_str = ''.join(f"{v}&" for k, v in params_list)[:-1]
-        sign = hashlib.md5(params_str.encode('utf-8')).hexdigest()
-        return sign
+    def get_sign(self, params_map):
+        params_list = []
+        for k, v in params_map.items():
+            if k == "other_settle_params":
+                continue
+            value = str(v).strip()
+            if value.startswith("\"") and value.endswith("\"") and len(value) > 1:
+                value = value[1: len(value) - 1]
+            value = value.strip()
+            if value == "" or value == "null":
+                continue
+            if k not in ("app_id", "thirdparty_id", "sign"):
+                params_list.append(value)
+        params_list.append(self.salt)
+        params_list.sort()
+        original_str = str("&").join(params_list)
+        return hashlib.md5(original_str.encode("utf-8")).hexdigest()
 
 
 class TikTokReponse(object):
@@ -568,7 +564,7 @@ class TikTokReponse(object):
     logger_error = Logger.get_logger_by_name("log_error")
 
     def __init__(self, data, token=""):
-        self.data = data  #data由json.loads(self.request.body)获得
+        self.data = json.loads(data)  #data由json.loads(self.request.body)获得
         pay_config = config.get_value("tiktok_pay")
         self.token = token if token else pay_config["token"]
 
@@ -587,7 +583,7 @@ class TikTokReponse(object):
         :last_editors: HuangJianYi
         """
         #计算服务端sign
-        service_signature = self._get_tt_callback_sign(self.data)
+        service_signature = self.get_callback_sign(self.data)
         #验证成功,进行业务处理
         log_msg = f'客户端签名:{self.data["msg_signature"]},服务端签名:{service_signature}'
         # self.logger_error.error(log_msg)
@@ -596,7 +592,7 @@ class TikTokReponse(object):
         else:
             return False
 
-    def _get_tt_callback_sign(self, params):
+    def get_callback_sign(self, params):
         """
         :description: 获取头条回调sign
         :param params: 参数字典
@@ -605,11 +601,16 @@ class TikTokReponse(object):
         """
         keys = ['type', 'msg_signature']
         params_copy = {key: params[key] for key in params if key not in keys}
-        for key, value in params_copy.items():
+        for key, v in params_copy.items():
+            value = str(v).strip()
+            if value.startswith("\"") and value.endswith("\"") and len(value) > 1:
+                value = value[1:len(value) - 1]
+            value = value.strip()
+            if value == "" or value == "null":
+                continue
             if isinstance(value, int):
                 params_copy[key] = str(value)
         params_copy['token'] = self.token
-        # params_copy['salt'] = 'your_payment_salt'
         params_list = sorted(list(params_copy.items()), key=lambda x: x[1])
         params_str = ''.join(f"{v}" for k, v in params_list)
         sign = CryptoHelper().sha1_encrypt(params_str)
@@ -621,7 +622,7 @@ class TikTokReponse(object):
         :return:
         :last_editors: HuangJianYi
         """
-        return {}
+        return {"err_no": err_no, "err_tips": err_tips}
 
 
 class TikTokBizDataCrypt:
