@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-12-21 15:20:21
+@LastEditTime: 2021-12-21 19:38:19
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -1020,9 +1020,11 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_member_info(self, access_token,app_key, app_secret, is_log=False):
+    def get_member_info(self, mix_nick, nick, access_token, app_key, app_secret, is_log=False):
         """
         :description: 获取淘宝会员信息
+        :param mix_nick:mix_nick
+        :param nick:nick
         :param access_token:access_token
         :param app_key:app_key
         :param app_secret:app_secret
@@ -1034,6 +1036,10 @@ class TopBaseModel():
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.CrmMemberIdentityGetRequest()
+            if mix_nick:
+                req.mix_nick = mix_nick
+            if nick:
+                req.nick = nick
             resp = req.getResponse(access_token)
             if is_log:
                 if self.context:
@@ -1061,9 +1067,11 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def check_is_member(self, access_token,app_key, app_secret,is_log=False):
+    def check_is_member(self, mix_nick, nick, access_token, app_key, app_secret, is_log=False):
         """
         :description: 实时查询当前是否店铺会员
+        :param mix_nick:mix_nick
+        :param nick:nick
         :param access_token:access_token
         :param app_key:app_key
         :param app_secret:app_secret
@@ -1072,7 +1080,7 @@ class TopBaseModel():
         :last_editors: HuangJianYi
         """
         is_member = False
-        invoke_result_data = self.get_member_info(access_token,app_key, app_secret,is_log)
+        invoke_result_data = self.get_member_info(mix_nick, nick, access_token, app_key, app_secret, is_log)
         if invoke_result_data.success == False:
             return is_member
         resp = invoke_result_data.data
